pub struct BoundingBox {
pub width: f32,
pub height: f32,
pub position: Vector3<f32>,
}Expand description
Structure representing the bounding box
Fields
width: f32Width of the bounding box
height: f32Height of the bounding box
position: Vector3<f32>Position of the bounding box.
Use 0.0 for the third value and ignore it if the bounding box is in a 2D dimension
Implementations
Sourceimpl BoundingBox
impl BoundingBox
Sourcepub fn new(width: f32, height: f32, position: Vector3<f32>) -> Self
pub fn new(width: f32, height: f32, position: Vector3<f32>) -> Self
Creates a new instance of BoundingBox
Arguments
width: width of the bounding boxheight: height of the bounding boxposition:Vector3<f32>of the bounding box. Use0.0for the third (z) value if the box is in a 2D dimension
Sourcepub fn check_collision(&self, other: &BoundingBox) -> bool
pub fn check_collision(&self, other: &BoundingBox) -> bool
Checks if a collision happened between two bounding boxes
Arguments
other: immutable reference to a box with which the collision should be checked
Examples
use nalgebra::Vector3;
use fennel_physics::aabb::BoundingBox;
let first_box = BoundingBox::new(10.0, 10.0, Vector3::new(3.0, 4.0, 0.0)); // 2d plane
let second_box = BoundingBox::new(10.0, 10.0, Vector3::new(3.0, 6.0, 0.0));
assert!(first_box.check_collision(&second_box)); // boxes collideTrait Implementations